__all__=['', 'ChangeClipboardChain', 'CloseClipboard', 'CountClipboardFormats', 'EmptyClipboard', 'EnumClipboardFormats', 'GetClipboardData', 'GetClipboardDataHandle', 'GetClipboardFormatName', 'GetClipboardOwner', 'GetClipboardSequenceNumber', 'GetClipboardViewer', 'GetGlobalMemory', 'GetOpenClipboardWindow', 'GetPriorityClipboardFormat', 'IsClipboardFormatAvailable', 'OpenClipboard', 'RegisterClipboardFormat', 'SetClipboardData', 'SetClipboardText', 'SetClipboardViewer']
import typing
import win32typing
"""A module which supports the Windows Clipboard API."""


def ChangeClipboardChain(hWndRemove:'typing.Any',hWndNewNext:'typing.Any') -> 'typing.Any':
    """
    The ChangeClipboardChain 

function removes a specified window from the chain of clipboard viewers.

Args:

      hWndRemove(typing.Any):Integer handle to the window to be removed from the chain. The handle must have been passed to the SetClipboardViewer function.
      hWndNewNext(typing.Any):Integer handle to the window that follows the hWndRemove window in the clipboard viewer chain. (This is the handle returned by SetClipboardViewer, unless the sequence was changed in response to a WM_CHANGECBCHAIN message.)CommentsThe window identified by hWndNewNext replaces the hWndRemove window in the chain. The SetClipboardViewer function sends a WM_CHANGECBCHAIN message to the first window in the clipboard viewer chain.Win32 API References

Returns:

      typing.Any:Search for ChangeClipboardChain at msdn, google or google groups.
Return ValueThe return value indicates the result of passing the 

WM_CHANGECBCHAIN message to the windows in the clipboard viewer chain. 

Because a window in the chain typically returns FALSE when it processes 

WM_CHANGECBCHAIN, the return value from ChangeClipboardChain is typically 

FALSE. If there is only one window in the chain, the return value is 

typically TRUE.

        
    """
    pass
        

def CloseClipboard() -> 'typing.Any':
    """
    None

Args:



Returns:

      typing.Any:Search for CloseClipboard at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is None. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def CountClipboardFormats() -> 'typing.Any':
    """
    The CountClipboardFormats 

function retrieves the number of different data formats currently on the 

clipboard.

Args:



Returns:

      typing.Any:Search for CountClipboardFormats at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is the number of 

different data formats currently on the clipboard. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def EmptyClipboard() -> 'typing.Any':
    """
    The EmptyClipboard function empties 

the clipboard and frees handles to data in the clipboard. The function then 

assigns ownership of the clipboard to the window that currently has the 

clipboard open.

Args:



Returns:

      typing.Any:Search for EmptyClipboard at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is None. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def EnumClipboardFormats(_format:'typing.Any'=0) -> 'typing.Any':
    """
    The EnumClipboardFormats 

function lets you enumerate the data formats that are currently available 

on the clipboard.

Args:

      _format(typing.Any):Specifies a clipboard format that is known to be available. To start an enumeration of clipboard formats, set format to zero. When format is zero, the function retrieves the first available clipboard format. For subsequent calls during an enumeration, set format to the result of the previous EnumClipboardFormat call.CommentsClipboard data formats are stored in an ordered list. To perform an enumeration of clipboard data formats, you make a series of calls to the EnumClipboardFormats function. For each call, the format parameter specifies an available clipboard format, and the function returns the next available clipboard format. You must open the clipboard before enumerating its formats. Use the OpenClipboard function to open the clipboard. The EnumClipboardFormats function fails if the clipboard is not open. The EnumClipboardFormats function enumerates formats in the order that they were placed on the clipboard. If you are copying information to the clipboard, add clipboard objects in order from the most descriptive clipboard format to the least descriptive clipboard format. If you are pasting information from the clipboard, retrieve the first clipboard format that you can handle. That will be the most descriptive clipboard format that you can handle. The system provides automatic type conversions for certain clipboard formats. In the case of such a format, this function enumerates the specified format, then enumerates the formats to which it can be converted.  For more information, see Standard Clipboard Formats and Synthesized Clipboard Formats.Win32 API References

Returns:

      typing.Any:Search for EnumClipboardFormats at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is the clipboard 

format that follows the specified format. In other words, the next 

available clipboard format. 

If there are no more clipboard formats to enumerate, the return value is 

zero. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def GetClipboardData(_format:'typing.Any') -> 'typing.Union[str, typing.Any]':
    """
    None

Args:

      _format(typing.Any):Specifies a clipboard format. For a description of the standard clipboard formats, see Standard Clipboard Formats. In Unicode builds (ie, python 3k), the default is CF_UNICODETEXT.CommentsAn application can enumerate the available formats in advance by using the EnumClipboardFormats function. The clipboard controls the handle that the GetClipboardData function returns, not the application. The application should copy the data immediately. The application cannot rely on being able to make long-term use of the handle. The application must not free the handle nor leave it locked. The system performs implicit data format conversions between certain clipboard formats when an application calls the GetClipboardData function. For example, if the CF_OEMTEXT format is on the clipboard, a window can retrieve data in the CF_TEXT format. The format on the clipboard is converted to the requested format on demand. For more information, see Synthesized Clipboard Formats.Win32 API References

Returns:

      typing.Union[str, typing.Any]:Search for Standard Clipboard Formats at msdn, google or google groups.
 To Do CF_METAFILEPICT format returns a pointer to a METAFILEPICT struct which contains the metafile 

handle, 

rather than returning the handle directly.  This code currently fails with 

error: (6, 'GetClipboardData:GetMetafileBitsEx(NULL)', 'The handle is invalid.')
Return ValueIf the function fails, the standard win32api.error exception 

is raised.  If the function succeeds, the return value is as 

described in the following table:



Format


Result type



CF_HDROPA tuple of Unicode filenames.
CF_UNICODETEXTA unicode object.
CF_OEMTEXTA string object.
CF_TEXTA string object.
CF_ENHMETAFILEA string with binary data obtained from GetEnhMetaFileBits
CF_METAFILEPICTA string with binary data obtained from GetMetaFileBitsEx (currently broken)
CF_BITMAPAn integer handle to the bitmap.
All other formatsA string with binary data obtained directly from the 

global memory referenced by the handle.

        
    """
    pass
        

def GetClipboardDataHandle(_format:'typing.Any') -> 'typing.Any':
    """
    None

Args:

      _format(typing.Any):Specifies a clipboard format. For a description of the standard clipboard formats, see Standard Clipboard Formats.

Returns:

      typing.Any
        
    """
    pass
        

def GetClipboardFormatName(_format:'typing.Any') -> 'str':
    """
    The GetClipboardFormatName 

function retrieves from the clipboard the name of the specified registered 

format.

Args:

      _format(typing.Any):Specifies the type of format to be retrieved. This parameter must not specify any of the predefined clipboard formats.Win32 API References

Returns:

      str:Search for GetClipboardFormatName at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is the string containing 

the format. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def GetClipboardOwner() -> 'typing.Any':
    """
    The GetClipboardOwner function 

retrieves the window handle of the current owner of the clipboard.

Args:



Returns:

      typing.Any:Search for GetClipboardOwner at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is the handle of the 

window that owns the clipboard. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def GetClipboardSequenceNumber() -> 'typing.Any':
    """
    The 

GetClipboardSequenceNumber function returns the clipboard sequence number 

for the current window station.

Args:



Returns:

      typing.Any:Search for GetClipboardSequenceNumber at msdn, google or google groups.
Return ValueThe return value is the clipboard sequence number. If you do not 

have WINSTA_ACCESSCLIPBOARD access to the window station, the function 

returns zero.

        
    """
    pass
        

def GetClipboardViewer() -> 'typing.Any':
    """
    The GetClipboardViewer function 

retrieves the handle of the first window in the clipboard viewer chain.

Args:



Returns:

      typing.Any:Search for GetClipboardViewer at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is the handle of the 

first window in the clipboard viewer chain. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def GetGlobalMemory(hglobal:'int') -> 'str':
    """
    Returns the contents of the specified 

global memory object.

Args:

      hglobal(int):The handle to the global memory object

Returns:

      str
        
    """
    pass
        

def GetOpenClipboardWindow() -> 'typing.Any':
    """
    The GetOpenClipboardWindow 

function retrieves the handle of the window that currently has the 

clipboard open.

Args:



Returns:

      typing.Any:Search for GetOpenClipboardWindow at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is the handle of the 

window that has the clipboard open. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def GetPriorityClipboardFormat(formats:'typing.Any') -> 'typing.Any':
    """
    Returns the first available clipboard format in the specified 

list.

Args:

      formats(typing.Any):Sequence of integers identifying clipboard formats, in priority order. For a description of the standard clipboard formats, see Standard Clipboard Formats.Win32 API References

Returns:

      typing.Any:Search for Standard Clipboard Formats at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is the first clipboard 

format in the list for which data is available. If the clipboard is 

empty, the return value is NULL. If the clipboard contains data, but not 

in any of the specified formats, the return value is -1.

        
    """
    pass
        

def IsClipboardFormatAvailable(_format:'typing.Any') -> 'typing.Any':
    """
    The 

IsClipboardFormatAvailable function determines whether the clipboard 

contains data in the specified format.

Args:

      _format(typing.Any):Specifies a clipboard format. For a description of the standard clipboard formats, see Standard Clipboard Formats.CommentsTypically, an application that recognizes only one clipboard format would call this function when processing the WM_INITMENU or WM_INITMENUPOPUP message. The application would then enable or disable the Paste menu item, depending on the return value. Applications that recognize more than one clipboard format should use the GetPriorityClipboardFormat function for this purpose.Win32 API References

Returns:

      typing.Any:Search for Standard Clipboard Formats at msdn, google or google groups.
Return ValueIf the clipboard format is available, the return value is nonzero.

        
    """
    pass
        

def OpenClipboard(hWnd:'int'=None) -> 'typing.Any':
    """
    The OpenClipboard function opens the 

clipboard for examination and prevents other applications from modifying 

the clipboard content.

Args:

      hWnd(int):Integer handle to the window to be associated with the open clipboard. If this parameter is None, the open clipboard is associated with the current task.CommentsOpenClipboard fails if another window has the clipboard open. An application should call the CloseClipboard function after every successful call to OpenClipboard. The window identified by the hWnd parameter does not become the clipboard owner unless the EmptyClipboard function is called.Win32 API References

Returns:

      typing.Any:Search for OpenClipboard at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is None. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def RegisterClipboardFormat(name:'str') -> 'typing.Any':
    """
    The 

RegisterClipboardFormat function registers a new clipboard format. 

This format can then be used as a valid clipboard format.

Args:

      name(str):String that names the new format.CommentsIf a registered format with the specified name already exists, a new format is not registered and the return value identifies the existing format. This enables more than one application to copy and paste data using the same registered clipboard format. Note that the format name comparison is case-insensitive. Registered clipboard formats are identified by values in the range 0xC000 through 0xFFFF.Win32 API References

Returns:

      typing.Any:Search for RegisterClipboardFormat at msdn, google or google groups.
Return ValueIf the function succeeds, the return value identifies the 

registered clipboard format. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def SetClipboardData(_format:'typing.Any',hMem:'typing.Union[typing.Any]') -> 'typing.Any':
    """
    The SetClipboardData function 

places data on the clipboard in a specified clipboard format. The window 

must be the current clipboard owner, and the application must have called 

the OpenClipboard function. (When responding to the WM_RENDERFORMAT and 

WM_RENDERALLFORMATS messages, the clipboard owner must not call 

OpenClipboard before calling SetClipboardData.)

Args:

      _format(typing.Any):Specifies a clipboard format. For a description of the standard clipboard formats, see Standard Clipboard Formats.
      hMem(typing.Union[typing.Any]):Integer handle to the data in the specified format, or string, unicode, or any object that supports the buffer interface. A global memory object is allocated, and the object's buffer is copied to the new memory. This parameter can be 0, indicating that the window provides data in the specified clipboard format (renders the format) upon request. If a window delays rendering, it must process the WM_RENDERFORMAT and WM_RENDERALLFORMATS messages. After SetClipboardData is called, the system owns the object identified by the hMem parameter. The application can read the data, but must not free the handle or leave it locked. If the hMem parameter identifies a memory object, the object must have been allocated using the GlobalAlloc function with the GMEM_MOVEABLE and GMEM_DDESHARE flags.CommentsThe uFormat parameter can identify a registered clipboard format, or it can be one of the standard clipboard formats. For more information, see Registered Clipboard Formats and Standard Clipboard Formats. The system performs implicit data format conversions between certain clipboard formats when an application calls the GetClipboardData function. For example, if the CF_OEMTEXT format is on the clipboard, a window can retrieve data in the CF_TEXT format. The format on the clipboard is converted to the requested format on demand. For more information, see Synthesized Clipboard Formats.Win32 API References

Returns:

      typing.Any:Search for SetClipboardData at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is integer handle 

of the data. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def SetClipboardText(text:'typing.Union[typing.Any]',_format:'typing.Any') -> 'typing.Any':
    """
    Convienience function to 

call SetClipboardData with text.

Args:

      text(typing.Union[typing.Any]):The text to place on the clipboard.
      _format(typing.Any):The clipboard format to use - must be CF_TEXT or CF_UNICODETEXTCommentsYou may pass a Unicode or string/bytes object to this function, but depending on the value of the 'format' param, it may be converted to the appropriate type for that param.Many applications will want to call this function twice, with the same string specified but CF_UNICODETEXT specified the second.Win32 API References

Returns:

      typing.Any:Search for SetClipboardData at msdn, google or google groups.
Return ValueIf the function succeeds, the return value is integer handle 

of the data. 

If the function fails, win32api.error is raised with the GetLastError 

info.

        
    """
    pass
        

def SetClipboardViewer(hWndNewViewer:'int') -> 'int':
    """
    The SetClipboardViewer function 

adds the specified window to the chain of clipboard viewers. Clipboard 

viewer windows receive a WM_DRAWCLIPBOARD message whenever the content of 

the clipboard changes.

Args:

      hWndNewViewer(int):Integer handle to the window to be added to the clipboard chain.CommentsThe windows that are part of the clipboard viewer chain, called clipboard viewer windows, must process the clipboard messages WM_CHANGECBCHAIN and WM_DRAWCLIPBOARD. Each clipboard viewer window calls the SendMessage function to pass these messages to the next window in the clipboard viewer chain. A clipboard viewer window must eventually remove itself from the clipboard viewer chain by calling the ChangeClipboardChain function -- for example, in response to theWM_DESTROY message.Win32 API References

Returns:

      int:Search for SetClipboardViewer at msdn, google or google groups.
Return ValueReturns a handle to the next window in chain, or None if no other viewer exists.



If the function succeeds, the return value identifies the next 

window in the clipboard viewer chain. 

If an error occurs or there are no other windows in the clipboard viewer 

chain, win32api.error is raised with the GetLastError info.

        
    """
    pass
        


__all__=['', 'DirectSoundCreate', 'DirectSoundEnumerate', 'DirectSoundCaptureCreate', 'DirectSoundCaptureEnumerate', 'DSCAPS', 'DSBCAPS', 'DSCCAPS', 'DSCBCAPS', 'DSBUFFERDESC', 'DSCBUFFERDESC', 'DS3DMODE_DISABLE', 'DS3DMODE_HEADRELATIVE', 'DS3DMODE_NORMAL', 'DSBCAPS_CTRL3D', 'DSBCAPS_CTRLFREQUENCY', 'DSBCAPS_CTRLPAN', 'DSBCAPS_CTRLPOSITIONNOTIFY', 'DSBCAPS_CTRLVOLUME', 'DSBCAPS_GETCURRENTPOSITION2', 'DSBCAPS_GLOBALFOCUS', 'DSBCAPS_LOCHARDWARE', 'DSBCAPS_LOCSOFTWARE', 'DSBCAPS_MUTE3DATMAXDISTANCE', 'DSBCAPS_PRIMARYBUFFER', 'DSBCAPS_STATIC', 'DSBCAPS_STICKYFOCUS', 'DSBLOCK_ENTIREBUFFER', 'DSBLOCK_FROMWRITECURSOR', 'DSBPLAY_LOOPING', 'DSBSTATUS_BUFFERLOST', 'DSBSTATUS_LOOPING', 'DSBSTATUS_PLAYING', 'DSCAPS_CERTIFIED', 'DSCAPS_CONTINUOUSRATE', 'DSCAPS_EMULDRIVER', 'DSCAPS_PRIMARY16BIT', 'DSCAPS_PRIMARY8BIT', 'DSCAPS_PRIMARYMONO', 'DSCAPS_PRIMARYSTEREO', 'DSCAPS_SECONDARY16BIT', 'DSCAPS_SECONDARY8BIT', 'DSCAPS_SECONDARYMONO', 'DSCAPS_SECONDARYSTEREO', 'DSCBCAPS_WAVEMAPPED', 'DSCCAPS_EMULDRIVER', 'DSSCL_EXCLUSIVE', 'DSSCL_NORMAL', 'DSSCL_PRIORITY', 'DSSCL_WRITEPRIMARY', 'DSSPEAKER_GEOMETRY_MAX', 'DSSPEAKER_GEOMETRY_MIN', 'DSSPEAKER_GEOMETRY_NARROW', 'DSSPEAKER_GEOMETRY_WIDE', 'DSSPEAKER_HEADPHONE', 'DSSPEAKER_MONO', 'DSSPEAKER_QUAD', 'DSSPEAKER_STEREO', 'DSSPEAKER_SURROUND']
import typing
import win32typing
""""""


def DirectSoundCreate(guid:'win32typing.PyIID'=None,unk:'typing.Any'=None) -> 'win32typing.PyIUnknown':
    """
    Creates and initializes a new object that supports the 

IDirectSound interface.

Args:

      guid(win32typing.PyIID):Address of the GUID that identifies the sound device. The value of this parameter must be one of the GUIDs returned by DirectSoundEnumerate, or None for the default device.
      unk(typing.Any):The IUnknown for COM aggregation.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def DirectSoundEnumerate() -> 'typing.Any':
    """
    Enumerates DirectSound drivers installed in the system.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def DirectSoundCaptureCreate(guid:'win32typing.PyIID'=None,unk:'typing.Any'=None) -> 'win32typing.PyIUnknown':
    """
    Creates and initializes a new object that supports the 

IDirectSoundCapture interface.

Args:

      guid(win32typing.PyIID):Address of the GUID that identifies the sound device. The value of this parameter must be one of the GUIDs returned by DirectSoundCaptureEnumerate, or None for the default device.
      unk(typing.Any):The IUnknown for COM aggregation.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def DirectSoundCaptureEnumerate() -> 'typing.Any':
    """
    Enumerates DirectSoundCapture drivers installed in the 

system.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def DSCAPS() -> 'win32typing.PyDSCAPS':
    """
    Creates a new PyDSCAPS object.

Args:



Returns:

      win32typing.PyDSCAPS
        
    """
    pass
        

def DSBCAPS() -> 'win32typing.PyDSBCAPS':
    """
    Creates a new PyDSBCAPS object

Args:



Returns:

      win32typing.PyDSBCAPS
        
    """
    pass
        

def DSCCAPS() -> 'win32typing.PyDSCCAPS':
    """
    Creates a new PyDSCCAPS object

Args:



Returns:

      win32typing.PyDSCCAPS
        
    """
    pass
        

def DSCBCAPS() -> 'win32typing.PyDSCBCAPS':
    """
    Creates a new PyDSCBCAPS object

Args:



Returns:

      win32typing.PyDSCBCAPS
        
    """
    pass
        

def DSBUFFERDESC() -> 'win32typing.PyDSBUFFERDESC':
    """
    Creates a new PyDSBUFFERDESC object

Args:



Returns:

      win32typing.PyDSBUFFERDESC
        
    """
    pass
        

def DSCBUFFERDESC() -> 'win32typing.PyDSCBUFFERDESC':
    """
    Creates a new PyDSCBUFFERDESC object

Args:



Returns:

      win32typing.PyDSCBUFFERDESC
        
    """
    pass
        
DS3DMODE_DISABLE = ...
DS3DMODE_HEADRELATIVE = ...
DS3DMODE_NORMAL = ...
DSBCAPS_CTRL3D = ...
DSBCAPS_CTRLFREQUENCY = ...
DSBCAPS_CTRLPAN = ...
DSBCAPS_CTRLPOSITIONNOTIFY = ...
DSBCAPS_CTRLVOLUME = ...
DSBCAPS_GETCURRENTPOSITION2 = ...
DSBCAPS_GLOBALFOCUS = ...
DSBCAPS_LOCHARDWARE = ...
DSBCAPS_LOCSOFTWARE = ...
DSBCAPS_MUTE3DATMAXDISTANCE = ...
DSBCAPS_PRIMARYBUFFER = ...
DSBCAPS_STATIC = ...
DSBCAPS_STICKYFOCUS = ...
DSBLOCK_ENTIREBUFFER = ...
DSBLOCK_FROMWRITECURSOR = ...
DSBPLAY_LOOPING = ...
DSBSTATUS_BUFFERLOST = ...
DSBSTATUS_LOOPING = ...
DSBSTATUS_PLAYING = ...
DSCAPS_CERTIFIED = ...
DSCAPS_CONTINUOUSRATE = ...
DSCAPS_EMULDRIVER = ...
DSCAPS_PRIMARY16BIT = ...
DSCAPS_PRIMARY8BIT = ...
DSCAPS_PRIMARYMONO = ...
DSCAPS_PRIMARYSTEREO = ...
DSCAPS_SECONDARY16BIT = ...
DSCAPS_SECONDARY8BIT = ...
DSCAPS_SECONDARYMONO = ...
DSCAPS_SECONDARYSTEREO = ...
DSCBCAPS_WAVEMAPPED = ...
DSCCAPS_EMULDRIVER = ...
DSSCL_EXCLUSIVE = ...
DSSCL_NORMAL = ...
DSSCL_PRIORITY = ...
DSSCL_WRITEPRIMARY = ...
DSSPEAKER_GEOMETRY_MAX = ...
DSSPEAKER_GEOMETRY_MIN = ...
DSSPEAKER_GEOMETRY_NARROW = ...
DSSPEAKER_GEOMETRY_WIDE = ...
DSSPEAKER_HEADPHONE = ...
DSSPEAKER_MONO = ...
DSSPEAKER_QUAD = ...
DSSPEAKER_STEREO = ...
DSSPEAKER_SURROUND = ...



__all__=['', 'RASEAPF_Logon', 'RASEAPF_NonInteractive', 'RASEAPF_Preview']
import typing
import win32typing
"""A module encapsulating the Windows 2000 extensions to the Remote Access Service (RAS) API."""

RASEAPF_Logon = ...
RASEAPF_NonInteractive = ...
RASEAPF_Preview = ...



__all__=['', 'GetNamedPipeHandleState', 'SetNamedPipeHandleState', 'ConnectNamedPipe', 'TransactNamedPipe', 'CallNamedPipe', 'CreatePipe', 'FdCreatePipe', 'CreateNamedPipe', 'DisconnectNamedPipe', 'GetOverlappedResult', 'WaitNamedPipe', 'GetNamedPipeInfo', 'PeekNamedPipe', 'GetNamedPipeClientProcessId', 'GetNamedPipeServerProcessId', 'GetNamedPipeClientSessionId', 'GetNamedPipeServerSessionId', 'popen', 'NMPWAIT_NOWAIT', 'NMPWAIT_USE_DEFAULT_WAIT', 'NMPWAIT_WAIT_FOREVER', 'PIPE_ACCESS_DUPLEX', 'PIPE_ACCESS_INBOUND', 'PIPE_ACCESS_OUTBOUND', 'PIPE_NOWAIT', 'PIPE_READMODE_BYTE', 'PIPE_READMODE_MESSAGE', 'PIPE_TYPE_BYTE', 'PIPE_TYPE_MESSAGE', 'PIPE_UNLIMITED_INSTANCES', 'PIPE_WAIT']
import typing
import win32typing
"""An interface to the win32 pipe API's"""


def GetNamedPipeHandleState(hPipe:'int',bGetCollectionData:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Union[typing.Any], typing.Union[typing.Any], str]':
    """
    Determines the state of the named pipe.

Args:

      hPipe(int):The handle to the pipe.
      bGetCollectionData(typing.Any):Determines of the collection data should be returned.  If not, None is returned in their place.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Union[typing.Any], typing.Union[typing.Any], str]
        
    """
    pass
        

def SetNamedPipeHandleState(hPipe:'int',Mode:'typing.Union[typing.Any]',MaxCollectionCount:'typing.Union[typing.Any]',CollectDataTimeout:'typing.Union[typing.Any]') -> 'None':
    """
    Sets the state of the named pipe.

Args:

      hPipe(int):The handle to the pipe.
      Mode(typing.Union[typing.Any]):The pipe read mode.
      MaxCollectionCount(typing.Union[typing.Any]):Maximum bytes collected before transmission to the server.
      CollectDataTimeout(typing.Union[typing.Any]):Maximum time to wait, in milliseconds, before transmission to server.

Returns:

      None
        
    """
    pass
        

def ConnectNamedPipe(hPipe:'int',overlapped:'win32typing.PyOVERLAPPED'=None) -> 'typing.Any':
    """
    Connects to a named pipe

Args:

      hPipe(int):The handle to the pipe.
      overlapped(win32typing.PyOVERLAPPED):An overlapped object to use, else NoneCommentsThe result is zero if the function succeeds.  If the function fails, GetLastError() is called, and if the result is ERROR_IO_PENDING or ERROR_PIPE_CONNECTED (common when passing an overlapped object), this value is returned.  All other error values raise a win32 exception (from which the error code can be extracted)

Returns:

      typing.Any
        
    """
    pass
        

def TransactNamedPipe(pipeName:'typing.Any',writeData:'typing.Union[str, typing.Any]',buffer_bufSize:'typing.Union[win32typing.PyOVERLAPPEDReadBuffer, typing.Any]',overlapped:'win32typing.PyOVERLAPPED'=None) -> 'typing.Union[str, typing.Any]':
    """
    Combines the functions that write a 

message to and read a message from the specified named pipe into a single 

network operation.

Args:

      pipeName(typing.Any):The name of the pipe.
      writeData(typing.Union[str, typing.Any]):The data to write to the pipe.
      buffer_bufSize(typing.Union[win32typing.PyOVERLAPPEDReadBuffer, typing.Any]):Size of the buffer to create for the result, or a buffer to fill with the result. If a buffer object and overlapped is passed, the result is the buffer itself.  If a buffer but no overlapped is passed, the result is a new string object, built from the buffer, but with a length that reflects the data actually read.
      overlapped(win32typing.PyOVERLAPPED):An overlapped structure or NoneCommentsThis function is modelled on win32file::ReadFile - for overlapped operations you are expected to provide a buffer which will be filled asynchronously.

Returns:

      typing.Union[str, typing.Any]
        
    """
    pass
        

def CallNamedPipe(pipeName:'typing.Any',data:'str',bufSize:'typing.Any',timeOut:'typing.Any') -> 'str':
    """
    Opens and performs a transaction on a named pipe.

Args:

      pipeName(typing.Any):The name of the pipe.
      data(str):The data to write.
      bufSize(typing.Any):The size of the result buffer to allocate for the read.
      timeOut(typing.Any):Specifies the number of milliseconds to wait for the named pipe to be available. In addition to numeric values, the following special values can be specified.ValueMeaningwin32pipe.NMPWAIT_NOWAITDoes not wait for the named pipe. If the named pipe is not available, the function returns an error.win32pipe.NMPWAIT_WAIT_FOREVERWaits indefinitely.win32pipe.NMPWAIT_USE_DEFAULT_WAITUses the default time-out specified in a call to the CreateNamedPipe function.

Returns:

      str
        
    """
    pass
        

def CreatePipe(sa:'win32typing.PySECURITY_ATTRIBUTES',nSize:'typing.Any') -> 'typing.Tuple[int, int]':
    """
    Creates an anonymous pipe, and returns handles to the read and write ends of the pipe

Args:

      sa(win32typing.PySECURITY_ATTRIBUTES):
      nSize(typing.Any):

Returns:

      typing.Tuple[int, int]
        
    """
    pass
        

def FdCreatePipe(sa:'win32typing.PySECURITY_ATTRIBUTES',nSize:'typing.Any',mode:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    As CreatePipe but returns file descriptors

Args:

      sa(win32typing.PySECURITY_ATTRIBUTES):Specifies security and inheritance for the pipe
      nSize(typing.Any):Buffer size for pipe.  Use 0 for default size.
      mode(typing.Any):O_TEXT or O_BINARY

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def CreateNamedPipe(pipeName:'str',openMode:'typing.Any',pipeMode:'typing.Any',nMaxInstances:'typing.Any',nOutBufferSize:'typing.Any',nInBufferSize:'typing.Any',nDefaultTimeOut:'typing.Any',sa:'win32typing.PySECURITY_ATTRIBUTES') -> 'int':
    """
    Creates an instance of a named pipe and returns a handle for subsequent pipe operations

Args:

      pipeName(str):The name of the pipe
      openMode(typing.Any):OpenMode of the pipe
      pipeMode(typing.Any):
      nMaxInstances(typing.Any):
      nOutBufferSize(typing.Any):
      nInBufferSize(typing.Any):
      nDefaultTimeOut(typing.Any):
      sa(win32typing.PySECURITY_ATTRIBUTES):

Returns:

      int
        
    """
    pass
        

def DisconnectNamedPipe(hFile:'int') -> 'None':
    """
    Disconnects the server end of a named pipe instance from a client process.

Args:

      hFile(int):The handle to the pipe to disconnect.

Returns:

      None
        
    """
    pass
        

def GetOverlappedResult(hFile:'int',overlapped:'win32typing.PyOVERLAPPED',bWait:'typing.Any') -> 'typing.Any':
    """
    Determines the result of the most recent call with an OVERLAPPED object.

Args:

      hFile(int):The handle to the pipe or file
      overlapped(win32typing.PyOVERLAPPED):The overlapped object to check.
      bWait(typing.Any):Indicates if the function should wait for data to become available.CommentsThe result is the number of bytes transferred.  The overlapped object's attributes will be changed during this call.

Returns:

      typing.Any
        
    """
    pass
        

def WaitNamedPipe(pipeName:'str',timeout:'typing.Any') -> 'None':
    """
    None

Args:

      pipeName(str):The name of the pipe
      timeout(typing.Any):The number of milliseconds the function will wait. instead of a literal value, you can specify one of the following values for the timeout:ValueMeaningNMPWAIT_USE_DEFAULT_WAITThe time-out interval is the default value specified by the server process in the CreateNamedPipe function.NMPWAIT_WAIT_FOREVERThe function does not return until an instance of the named pipe is available

Returns:

      None
        
    """
    pass
        

def GetNamedPipeInfo(hNamedPipe:'int') -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Returns pipe's flags, buffer sizes, and max instances

Args:

      hNamedPipe(int):Handle to a named pipe

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]
        
    """
    pass
        

def PeekNamedPipe(hPipe:'int',size:'typing.Any') -> 'typing.Tuple[str, typing.Any, typing.Any]':
    """
    Copies data from a named or anonymous pipe into a buffer without removing it from the pipe. It also returns information about data in the pipe.

Args:

      hPipe(int):The handle to the pipe.
      size(typing.Any):The size of the buffer.

Returns:

      typing.Tuple[str, typing.Any, typing.Any]
        
    """
    pass
        

def GetNamedPipeClientProcessId(hPipe:'int') -> 'typing.Any':
    """
    Returns the process id of client that is connected to a named pipe

Args:

      hPipe(int):The handle to the pipe.CommentsRequires Vista or later

Returns:

      typing.Any
        
    """
    pass
        

def GetNamedPipeServerProcessId(hPipe:'int') -> 'typing.Any':
    """
    Returns pid of server process that created a named pipe

Args:

      hPipe(int):The handle to the pipe.CommentsRequires Vista or later

Returns:

      typing.Any
        
    """
    pass
        

def GetNamedPipeClientSessionId(hPipe:'int') -> 'typing.Any':
    """
    Returns the session id of client that is connected to a named pipe

Args:

      hPipe(int):The handle to the pipe.CommentsRequires Vista or later

Returns:

      typing.Any
        
    """
    pass
        

def GetNamedPipeServerSessionId(hPipe:'int') -> 'typing.Any':
    """
    Returns session id of server process that created a named pipe

Args:

      hPipe(int):The handle to the pipe.CommentsRequires Vista or later

Returns:

      typing.Any
        
    """
    pass
        

def popen(cmdstring:'str',mode:'str') -> 'typing.Any':
    """
    Popen that works from a GUI.

Args:

      cmdstring(str):The cmdstring to pass to the shell
      mode(str):Either 'r' or 'w'Return ValueThe result of this function is a pipe (file) connected to the processes stdin or stdout, depending on the requested mode.

Returns:

      typing.Any:Either 'r' or 'w'Return ValueThe result of this function is a pipe (file) connected to the 

processes stdin or stdout, depending on the requested mode.

        
    """
    pass
        
NMPWAIT_NOWAIT = ...
NMPWAIT_USE_DEFAULT_WAIT = ...
NMPWAIT_WAIT_FOREVER = ...
PIPE_ACCESS_DUPLEX = ...
PIPE_ACCESS_INBOUND = ...
PIPE_ACCESS_OUTBOUND = ...
PIPE_NOWAIT = ...
PIPE_READMODE_BYTE = ...
PIPE_READMODE_MESSAGE = ...
PIPE_TYPE_BYTE = ...
PIPE_TYPE_MESSAGE = ...
PIPE_UNLIMITED_INSTANCES = ...
PIPE_WAIT = ...



__all__=['', 'OpenPrinter', 'GetPrinter', 'SetPrinter', 'ClosePrinter', 'AddPrinterConnection', 'DeletePrinterConnection', 'EnumPrinters', 'GetDefaultPrinter', 'GetDefaultPrinterW', 'SetDefaultPrinter', 'SetDefaultPrinterW', 'StartDocPrinter', 'EndDocPrinter', 'AbortPrinter', 'StartPagePrinter', 'EndPagePrinter', 'StartDoc', 'EndDoc', 'AbortDoc', 'StartPage', 'EndPage', 'WritePrinter', 'EnumJobs', 'GetJob', 'SetJob', 'DocumentProperties', 'EnumPrintProcessors', 'EnumPrintProcessorDatatypes', 'EnumPrinterDrivers', 'EnumForms', 'AddForm', 'DeleteForm', 'GetForm', 'SetForm', 'AddJob', 'ScheduleJob', 'DeviceCapabilities', 'GetDeviceCaps', 'EnumMonitors', 'EnumPorts', 'GetPrintProcessorDirectory', 'GetPrinterDriverDirectory', 'AddPrinter', 'DeletePrinter', 'DeletePrinterDriver', 'DeletePrinterDriverEx', 'FlushPrinter']
import typing
import win32typing
"""A module encapsulating the Windows printing API."""


def OpenPrinter(printer:'str',Defaults:'typing.Any'=None) -> 'win32typing.PyPrinterHANDLE':
    """
    Retrieves a handle to a printer.

Args:

      printer(str):Printer or print server name.  Use None to open local print server.
      Defaults(typing.Any):PRINTER_DEFAULTS dict, or None

Returns:

      win32typing.PyPrinterHANDLE
        
    """
    pass
        

def GetPrinter(hPrinter:'win32typing.PyPrinterHANDLE',Level:'typing.Any'=2) -> 'typing.Any':
    """
    Retrieves information about a printer

Args:

      hPrinter(win32typing.PyPrinterHANDLE):handle to printer object as returned by win32print::OpenPrinter
      Level(typing.Any):Level of data returned (1,2,3,4,5,7,8,9)CommentsOriginal implementation used level 2 only and returned a tuple Pass single arg as indicator to use old behaviour for backward compatibilityReturn ValueReturns a dictionary containing PRINTER_INFO_* data for level, or returns a tuple of PRINTER_INFO_2 data if no level is passed in.

Returns:

      typing.Any:Level of data returned (1,2,3,4,5,7,8,9)
Comments

Original implementation used level 2 only and returned a tuple 

Pass single arg as indicator to use old behaviour for backward compatibility
Return ValueReturns a dictionary containing PRINTER_INFO_* data for level, or 

returns a tuple of PRINTER_INFO_2 data if no level is passed in.

        
    """
    pass
        

def SetPrinter(hPrinter:'win32typing.PyPrinterHANDLE',Level:'typing.Any',pPrinter:'typing.Any',Command:'typing.Any') -> 'None':
    """
    Change printer configuration and status

Args:

      hPrinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter
      Level(typing.Any):Level of data contained in pPrinter
      pPrinter(typing.Any):PRINTER_INFO_* dict as returned by win32print::GetPrinter, can be None if level is 0
      Command(typing.Any):Command to send to printer - one of the PRINTER_CONTROL_* constants, or 0CommentsIf Level is 0 and Command is PRINTER_CONTROL_SET_STATUS, pPrinter should be an integer, and is interpreted as the new printer status to set (one of the PRINTER_STATUS_* constants).

Returns:

      None
        
    """
    pass
        

def ClosePrinter(hPrinter:'win32typing.PyPrinterHANDLE') -> 'None':
    """
    Closes a handle to a printer.

Args:

      hPrinter(win32typing.PyPrinterHANDLE):handle to printer object

Returns:

      None
        
    """
    pass
        

def AddPrinterConnection(printer:'str') -> 'typing.Any':
    """
    Connects to remote printer

Args:

      printer(str):printer to connect to (eg: \\server\\printer).

Returns:

      typing.Any
        
    """
    pass
        

def DeletePrinterConnection(printer:'str') -> 'typing.Any':
    """
    Removes connection to remote printer

Args:

      printer(str):printer to disconnect from (eg: \\server\\printer).

Returns:

      typing.Any
        
    """
    pass
        

def EnumPrinters(flags:'typing.Any',name:'str'=None,level:'typing.Any'=1) -> 'typing.Any':
    """
    Enumerates printers, print servers, domains and print providers.

Args:

      flags(typing.Any):types of printer objects to enumerate (combination of PRINTER_ENUM_* constants).
      name(str):name of printer object.
      level(typing.Any):type of printer info structure (Levels 1,2,4,5 supported)CommentsUse Flags=PRINTER_ENUM_NAME, Name=None, Level=1 to enumerate print providers. Use Flags=PRINTER_ENUM_NAME, Name=\\servername, Level=2 or 5 to list printers on another server. See MSDN docs for EnumPrinters for other specific combinationsReturn ValueLevel 1 returns a tuple of tuples for backward compatibility. Each individual element is a tuple of (flags, description, name, comment) All other levels return a tuple of dictionaries representing PRINTER_INFO_* structures

Returns:

      typing.Any:type of printer info structure (Levels 1,2,4,5 supported)
Comments

Use Flags=PRINTER_ENUM_NAME, Name=None, Level=1 to enumerate print providers. 

Use Flags=PRINTER_ENUM_NAME, Name=\\servername, Level=2 or 5 to list printers on another server. 

See MSDN docs for EnumPrinters for other specific combinations
Return ValueLevel 1 returns a tuple of tuples for backward compatibility. 

Each individual element is a tuple of (flags, description, name, comment) 

All other levels return a tuple of dictionaries representing PRINTER_INFO_* structures

        
    """
    pass
        

def GetDefaultPrinter() -> 'str':
    """
    Returns the default printer.

Args:



Returns:

      str
        
    """
    pass
        

def GetDefaultPrinterW() -> 'str':
    """
    Returns the default printer.

Args:



Returns:

      str
        
    """
    pass
        

def SetDefaultPrinter(printer:'str') -> 'typing.Any':
    """
    Sets the default printer.

Args:

      printer(str):printer to set as defaultCommentsThis function uses the pre-win2k method of WriteProfileString rather than the SetDefaultPrinter API function

Returns:

      typing.Any
        
    """
    pass
        

def SetDefaultPrinterW(Printer:'str') -> 'typing.Any':
    """
    Sets the default printer

Args:

      Printer(str):Name of printer, can be None to use first available printerCommentsUnlike win32print::SetDefaultPrinter, this method calls the SetDefaultPrinter API function.

Returns:

      typing.Any
        
    """
    pass
        

def StartDocPrinter(hprinter:'win32typing.PyPrinterHANDLE',_tuple:'typing.Any',level:'typing.Any'=1) -> 'typing.Any':
    """
    Notifies the print spooler that a document is to be spooled for printing. To 

be used before using WritePrinter. Returns the Jobid of the started job.

Args:

      hprinter(win32typing.PyPrinterHANDLE):handle to printer (from win32print::OpenPrinter)
      _tuple(typing.Any):A tuple corresponding to the level parameter.CommentsFor level 1, the tuple is:Items[0] string : docNameSpecifies the name of the document.[1] string : outputFileSpecifies the name of an output file. To print to a printer, set this to None.[2] string : dataTypeIdentifies the type of data used to record the document, such as "raw" or "emf", used to record the print job. This member can be None. If it is not None, the StartDoc function passes it to the printer driver. Note that the printer driver might ignore the requested data type.
      level(typing.Any):type of docinfo structure (only docinfo level 1 supported)

Returns:

      typing.Any
        
    """
    pass
        

def EndDocPrinter(hPrinter:'win32typing.PyPrinterHANDLE') -> 'typing.Any':
    """
    The EndDocPrinter function ends a print job for the specified printer. To be 

used after using WritePrinter.

Args:

      hPrinter(win32typing.PyPrinterHANDLE):handle to printer (from win32print::OpenPrinter)

Returns:

      typing.Any
        
    """
    pass
        

def AbortPrinter(hPrinter:'win32typing.PyPrinterHANDLE') -> 'None':
    """
    Deletes spool file for a printer

Args:

      hPrinter(win32typing.PyPrinterHANDLE):Handle to printer as returned by win32print::OpenPrinter

Returns:

      None
        
    """
    pass
        

def StartPagePrinter(hprinter:'win32typing.PyPrinterHANDLE') -> 'None':
    """
    Notifies the print spooler that a page is to be printed on specified printer

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter

Returns:

      None
        
    """
    pass
        

def EndPagePrinter(hprinter:'win32typing.PyPrinterHANDLE') -> 'None':
    """
    Ends a page in a print job

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter

Returns:

      None
        
    """
    pass
        

def StartDoc(hdc:'int',docinfo:'typing.Any') -> 'typing.Any':
    """
    Starts spooling a print job on a printer device context

Args:

      hdc(int):Printer device context handle as returned by win32gui::CreateDC
      docinfo(typing.Any):DOCINFO tuple specifying print job parametersReturn ValueOn success, returns the job id of the print job

Returns:

      typing.Any:DOCINFO tuple specifying print job parametersReturn ValueOn success, returns the job id of the print job

        
    """
    pass
        

def EndDoc(hdc:'int') -> 'None':
    """
    Stops spooling a print job on a printer device context

Args:

      hdc(int):Printer device context handle as returned by win32gui::CreateDC

Returns:

      None
        
    """
    pass
        

def AbortDoc(hdc:'int') -> 'None':
    """
    Cancels a print job

Args:

      hdc(int):Printer device context handle as returned by win32gui::CreateDC

Returns:

      None
        
    """
    pass
        

def StartPage(hdc:'int') -> 'None':
    """
    Starts a page on a printer device context

Args:

      hdc(int):Printer device context handle as returned by win32gui::CreateDC

Returns:

      None
        
    """
    pass
        

def EndPage(hdc:'int') -> 'None':
    """
    Ends a page on a printer device context

Args:

      hdc(int):Printer device context handle as returned by win32gui::CreateDC

Returns:

      None
        
    """
    pass
        

def WritePrinter(hprinter:'win32typing.PyPrinterHANDLE',buf:'str') -> 'typing.Any':
    """
    Copies the specified bytes to the specified printer. 

Suitable for copying raw Postscript or HPGL files to a printer. 

StartDocPrinter and EndDocPrinter should be called before and after.

Args:

      hprinter(win32typing.PyPrinterHANDLE):Handle to printer as returned by win32print::OpenPrinter.
      buf(str):String or buffer containing data to send to printer. Embedded NULL bytes are allowed.Return ValueReturns number of bytes written to printer.

Returns:

      typing.Any:String or buffer containing data to send to printer. Embedded 

NULL bytes are allowed.Return ValueReturns number of bytes written to printer.

        
    """
    pass
        

def EnumJobs(hPrinter:'win32typing.PyPrinterHANDLE',FirstJob:'typing.Any',NoJobs:'typing.Any',Level:'typing.Any'=1) -> 'typing.Any':
    """
    Enumerates print jobs on specified printer.

Args:

      hPrinter(win32typing.PyPrinterHANDLE):Handle of printer.
      FirstJob(typing.Any):location of first job in print queue to enumerate.
      NoJobs(typing.Any):Number of jobs to enumerate.
      Level(typing.Any):Level of information to return (JOB_INFO_1, JOB_INFO_2, JOB_INFO_3 supported).Return ValueReturns a sequence of dictionaries representing JOB_INFO_* structures, depending on level

Returns:

      typing.Any:Level of information to return (JOB_INFO_1, JOB_INFO_2, 

JOB_INFO_3 supported).
Return ValueReturns a sequence of dictionaries representing JOB_INFO_* structures, depending on level

        
    """
    pass
        

def GetJob(hPrinter:'win32typing.PyPrinterHANDLE',JobID:'typing.Any',Level:'typing.Any'=1) -> 'typing.Any':
    """
    Returns dictionary of information about a specified print job.

Args:

      hPrinter(win32typing.PyPrinterHANDLE):Handle to a printer as returned by win32print::OpenPrinter.
      JobID(typing.Any):Job Identifier.
      Level(typing.Any):Level of information to return (JOB_INFO_1, JOB_INFO_2, JOB_INFO_3 supported).Return ValueReturns a dict representing a JOB_INFO_* struct, depending on level

Returns:

      typing.Any:Level of information to return (JOB_INFO_1, JOB_INFO_2, 

JOB_INFO_3 supported).
Return ValueReturns a dict representing a JOB_INFO_* struct, depending on level

        
    """
    pass
        

def SetJob(hPrinter:'win32typing.PyPrinterHANDLE',JobID:'typing.Any',Level:'typing.Any',JobInfo:'typing.Any',Command:'typing.Any') -> 'typing.Any':
    """
    Pause, cancel, resume, set priority levels on a print job.

Args:

      hPrinter(win32typing.PyPrinterHANDLE):Handle of printer.
      JobID(typing.Any):Job Identifier.
      Level(typing.Any):Level of information in JobInfo dict (0, 1, 2, and 3 are supported).
      JobInfo(typing.Any):JOB_INFO_* Dictionary as returned by win32print::GetJob or win32print::EnumJobs (can be None if Level is 0).
      Command(typing.Any):Job command value (JOB_CONTROL_*).CommentsIf printer is not opened with at least PRINTER_ACCESS_ADMINISTER access, 'Position' member of JOB_INFO_1 and JOB_INFO_2 must be set to JOB_POSITION_UNSPECIFIED

Returns:

      typing.Any
        
    """
    pass
        

def DocumentProperties(HWnd:'int',hPrinter:'win32typing.PyPrinterHANDLE',DeviceName:'str',DevModeOutput:'win32typing.PyDEVMODE',DevModeInput:'win32typing.PyDEVMODE',Mode:'typing.Any') -> 'typing.Any':
    """
    Changes printer configuration for a printer

Args:

      HWnd(int):Parent window handle to use if DM_IN_PROMPT is specified to display printer dialog
      hPrinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter
      DeviceName(str):Name of printer
      DevModeOutput(win32typing.PyDEVMODE):PyDEVMODE object that receives modified info, can be None if DM_OUT_BUFFER not specified
      DevModeInput(win32typing.PyDEVMODE):PyDEVMODE that specifies initial configuration, can be None if DM_IN_BUFFER not specified
      Mode(typing.Any):A combination of DM_IN_BUFFER, DM_OUT_BUFFER, and DM_IN_PROMPT - pass 0 to retrieve driver data sizeReturn ValueIf DM_IN_PROMPT is specified, returned value will be IDOK or IDCANCEL

Returns:

      typing.Any:A combination of DM_IN_BUFFER, DM_OUT_BUFFER, and DM_IN_PROMPT - pass 0 to retrieve driver data 

sizeReturn ValueIf DM_IN_PROMPT is specified, returned value will be IDOK or IDCANCEL

        
    """
    pass
        

def EnumPrintProcessors(Server:'typing.Union[str]'=None,Environment:'typing.Union[str]'=None) -> 'typing.Tuple[str, ...]':
    """
    List printer processors for specified server and 

environment

Args:

      Server(typing.Union[str]):Name of print server, use None for local machine
      Environment(typing.Union[str]):Environment - eg 'Windows NT x86' - use None for current client environment

Returns:

      typing.Tuple[str, ...]
        
    """
    pass
        

def EnumPrintProcessorDatatypes(ServerName:'typing.Union[str]',PrintProcessorName:'typing.Union[str]') -> 'typing.Tuple[str, ...]':
    """
    List data types that specified print provider 

recognizes

Args:

      ServerName(typing.Union[str]):Name of print server, use None for local machine
      PrintProcessorName(typing.Union[str]):Name of print processor

Returns:

      typing.Tuple[str, ...]
        
    """
    pass
        

def EnumPrinterDrivers(Server:'typing.Union[str, typing.Any]'=None,Environment:'typing.Union[str, typing.Any]'=None,Level:'typing.Any'=1) -> 'typing.Tuple[typing.Any, ...]':
    """
    Lists installed printer drivers

Args:

      Server(typing.Union[str, typing.Any]):Name of print server, use None for local machine
      Environment(typing.Union[str, typing.Any]):Environment - eg 'Windows NT x86' - use None for current client environment
      Level(typing.Any):Level of information to return, 1-6 (not all levels are supported on all platforms)CommentsOn Win2k and up, 'all' can be passed for environmentReturn ValueReturns a sequence of dictionaries representing DRIVER_INFO_* structures

Returns:

      typing.Tuple[typing.Any, ...]:Level of information to return, 1-6 (not all levels are supported on all platforms)
Comments

On Win2k and up, 'all' can be passed for environment
Return ValueReturns a sequence of dictionaries representing DRIVER_INFO_* structures

        
    """
    pass
        

def EnumForms(hprinter:'win32typing.PyPrinterHANDLE') -> 'typing.Tuple[win32typing.FORM_INFO_1, ...]':
    """
    Lists forms for a printer

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinterReturn ValueReturns a sequence of dictionaries representing FORM_INFO_1 structures

Returns:

      typing.Tuple[win32typing.FORM_INFO_1, ...]:Printer handle as returned by win32print::OpenPrinterReturn ValueReturns a sequence of dictionaries representing FORM_INFO_1 structures

        
    """
    pass
        

def AddForm(hprinter:'win32typing.PyPrinterHANDLE',Form:'typing.Any') -> 'None':
    """
    Adds a form for a printer

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter
      Form(typing.Any):FORM_INFO_1 dictionaryReturn ValueReturns None on success, throws an exception otherwise

Returns:

      None:FORM_INFO_1 dictionaryReturn ValueReturns None on success, throws an exception otherwise

        
    """
    pass
        

def DeleteForm(hprinter:'win32typing.PyPrinterHANDLE',FormName:'str') -> 'None':
    """
    Deletes a form defined for a printer

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter
      FormName(str):Name of form to be deletedReturn ValueReturns None on success, throws an exception otherwise

Returns:

      None:Name of form to be deletedReturn ValueReturns None on success, throws an exception otherwise

        
    """
    pass
        

def GetForm(hprinter:'win32typing.PyPrinterHANDLE',FormName:'str') -> 'None':
    """
    Retrieves information about a form defined for a printer

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter
      FormName(str):Name of form for which to retrieve infoReturn ValueReturns a FORM_INFO_1 dict

Returns:

      None:Name of form for which to retrieve infoReturn ValueReturns a FORM_INFO_1 dict

        
    """
    pass
        

def SetForm(hprinter:'win32typing.PyPrinterHANDLE',FormName:'str',Form:'typing.Any') -> 'None':
    """
    Change information for a form

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter
      FormName(str):Name of form
      Form(typing.Any):FORM_INFO_1 dictionaryReturn ValueReturns None on success

Returns:

      None:FORM_INFO_1 dictionaryReturn ValueReturns None on success

        
    """
    pass
        

def AddJob(hprinter:'win32typing.PyPrinterHANDLE') -> 'None':
    """
    Add a job to be spooled to a printer queue

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinterReturn ValueReturns the file name to which data should be written and the job id of the new job

Returns:

      None:Printer handle as returned by win32print::OpenPrinterReturn ValueReturns the file name to which data should be written and the job id of the new job

        
    """
    pass
        

def ScheduleJob(hprinter:'win32typing.PyPrinterHANDLE',JobId:'typing.Any') -> 'None':
    """
    Schedules a spooled job to be printed

Args:

      hprinter(win32typing.PyPrinterHANDLE):Printer handle as returned by win32print::OpenPrinter
      JobId(typing.Any):Job Id as returned by win32print::AddJob

Returns:

      None
        
    """
    pass
        

def DeviceCapabilities(Device:'str',Port:'str',Capability:'typing.Any',DEVMODE:'win32typing.PyDEVMODE'=None) -> 'None':
    """
    Queries a printer for its capabilities

Args:

      Device(str):Name of printer
      Port(str):Port that printer is using
      Capability(typing.Any):Type of capability to return - DC_* constant
      DEVMODE(win32typing.PyDEVMODE):If present, function returns values from it, otherwise the printer defaults are usedCapabilityReturned valueDC_MINEXTENTDictionary containing minimum paper width and heightDC_MAXEXTENTDictionary containing maximum paper width and heightDC_ENUMRESOLUTIONSSequence of dictionaries containing x and y resolutions in DPIDC_PAPERSReturns a sequence of ints, DMPAPER_* constantsDC_BINSReturns a sequence of ints, DMBIN_* constantsDC_NUPSequence of ints containing supported logical page per physical page settingsDC_MEDIATYPESSequence of ints, DMMEDIA_* constantsDC_PAPERNAMESSequence of stringsDC_MEDIATYPENAMESSequence of stringsDC_MEDIAREADYSequence of stringsDC_FILEDEPENDENCIESSequence of stringsDC_PERSONALITYSequence of stringsDC_BINNAMESSequence of stringsDC_PAPERSIZESequence of dicts containing paper sizes, in 1/10 millimeter unitsAll othersOutput is an int

Returns:

      None
        
    """
    pass
        

def GetDeviceCaps(hdc:'int',Index:'typing.Any') -> 'typing.Any':
    """
    Retrieves device-specific parameters and settings

Args:

      hdc(int):Handle to a printer or display device context
      Index(typing.Any):The capability to return.  See MSDN for valid values.CommentsCan also be used for Display DCs in addition to printer DCsWin32 API References

Returns:

      typing.Any
        
    """
    pass
        

def EnumMonitors(Name:'typing.Union[str, typing.Any]',Level:'typing.Any') -> 'typing.Tuple[typing.Any, ...]':
    """
    Lists installed printer port monitors

Args:

      Name(typing.Union[str, typing.Any]):Name of server, use None for local machine
      Level(typing.Any):Level of information to return, 1 and 2 supportedReturn ValueReturns a sequence of dicts representing MONITOR_INFO_* structures depending on level

Returns:

      typing.Tuple[typing.Any, ...]:Level of information to return, 1 and 2 supportedReturn ValueReturns a sequence of dicts representing MONITOR_INFO_* structures depending on level

        
    """
    pass
        

def EnumPorts(Name:'typing.Union[str, typing.Any]',Level:'typing.Any') -> 'typing.Tuple[typing.Any, ...]':
    """
    Lists printer port on a server

Args:

      Name(typing.Union[str, typing.Any]):Name of server, use None for local machine
      Level(typing.Any):Level of information to return, 1 and 2 supportedReturn ValueReturns a sequence of dicts representing PORT_INFO_* structures depending on level

Returns:

      typing.Tuple[typing.Any, ...]:Level of information to return, 1 and 2 supportedReturn ValueReturns a sequence of dicts representing PORT_INFO_* structures depending on level

        
    """
    pass
        

def GetPrintProcessorDirectory(Name:'typing.Union[str, typing.Any]',Environment:'typing.Union[str, typing.Any]') -> 'str':
    """
    Returns the directory where print processor files 

reside

Args:

      Name(typing.Union[str, typing.Any]):Name of server, use None for local machine
      Environment(typing.Union[str, typing.Any]):Environment - eg 'Windows NT x86' - use None for current client environment

Returns:

      str
        
    """
    pass
        

def GetPrinterDriverDirectory(Name:'typing.Union[str, typing.Any]',Environment:'typing.Union[str, typing.Any]') -> 'str':
    """
    Returns the directory where printer drivers are 

installed

Args:

      Name(typing.Union[str, typing.Any]):Name of server, use None for local machine
      Environment(typing.Union[str, typing.Any]):Environment - eg 'Windows NT x86' - use None for current client environment

Returns:

      str
        
    """
    pass
        

def AddPrinter(Name:'str',Level:'typing.Any',pPrinter:'typing.Any') -> 'win32typing.PyPrinterHANDLE':
    """
    Installs a printer on a server

Args:

      Name(str):Name of server on which to install printer, None indicates local machine
      Level(typing.Any):Level of data contained in pPrinter, only level 2 currently supported
      pPrinter(typing.Any):PRINTER_INFO_2 dict as returned by win32print::GetPrinterCommentspPrinterName, pPortName, pDriverName, and pPrintProcessor are requiredReturn ValueReturns a handle to the new printer

Returns:

      win32typing.PyPrinterHANDLE:PRINTER_INFO_2 dict as returned by win32print::GetPrinterComments

pPrinterName, pPortName, pDriverName, and pPrintProcessor are required
Return ValueReturns a handle to the new printer

        
    """
    pass
        

def DeletePrinter(hPrinter:'win32typing.PyPrinterHANDLE') -> 'None':
    """
    Deletes an existing printer

Args:

      hPrinter(win32typing.PyPrinterHANDLE):Handle to printer as returned by win32print::OpenPrinter or win32print::AddPrinterCommentsPrinter handle must be opened for PRINTER_ACCESS_ADMINISTER If there are any pending print jobs for the printer, actual deletion does not happen until they are done

Returns:

      None
        
    """
    pass
        

def DeletePrinterDriver(Server:'typing.Union[str]',Environment:'typing.Union[str]',DriverName:'typing.Union[str]') -> 'None':
    """
    Removes the specified printer driver from a server

Args:

      Server(typing.Union[str]):Name of print server, use None for local machine
      Environment(typing.Union[str]):Environment - eg 'Windows NT x86' - use None for current client environment
      DriverName(typing.Union[str]):Name of driver to removeCommentsDoes not delete associated driver files - use win32print::DeletePrinterDriverEx if this is required

Returns:

      None
        
    """
    pass
        

def DeletePrinterDriverEx(Server:'typing.Union[str]',Environment:'typing.Union[str]',DriverName:'typing.Union[str]',DeleteFlag:'typing.Any',VersionFlag:'typing.Any') -> 'None':
    """
    Deletes a printer driver and its associated files

Args:

      Server(typing.Union[str]):Name of print server, use None for local machine
      Environment(typing.Union[str]):Environment - eg 'Windows NT x86' - use None for current client environment
      DriverName(typing.Union[str]):Name of driver to remove
      DeleteFlag(typing.Any):Combination of DPD_DELETE_SPECIFIC_VERSION, DPD_DELETE_UNUSED_FILES, and DPD_DELETE_ALL_FILES
      VersionFlag(typing.Any):Can be 0,1,2, or 3.  Only used if DPD_DELETE_SPECIFIC_VERSION is specified in DeleteFlag

Returns:

      None
        
    """
    pass
        

def FlushPrinter(Printer:'win32typing.PyPrinterHANDLE',Buf:'typing.Any',Sleep:'typing.Any') -> 'typing.Any':
    """
    Clears printer from error state if WritePrinter fails

Args:

      Printer(win32typing.PyPrinterHANDLE):Handle to a printer
      Buf(typing.Any):Data to be sent to printer
      Sleep(typing.Any):Number of milliseconds to suspend printerReturn ValueReturns the number of bytes actually written to the printer

Returns:

      typing.Any:Number of milliseconds to suspend printerReturn ValueReturns the number of bytes actually written to the printer

        
    """
    pass
        


__all__=['', 'GetThreadDesktop', 'EnumWindowStations', 'GetUserObjectInformation', 'SetUserObjectInformation', 'OpenWindowStation', 'OpenDesktop', 'CreateDesktop', 'OpenInputDesktop', 'GetProcessWindowStation', 'CreateWindowStation', 'EnumServicesStatus', 'EnumServicesStatusEx', 'EnumDependentServices', 'QueryServiceConfig', 'StartService', 'OpenService', 'OpenSCManager', 'CloseServiceHandle', 'QueryServiceStatus', 'QueryServiceStatusEx', 'SetServiceObjectSecurity', 'QueryServiceObjectSecurity', 'GetServiceKeyName', 'GetServiceDisplayName', 'SetServiceStatus', 'ControlService', 'DeleteService', 'CreateService', 'ChangeServiceConfig', 'LockServiceDatabase', 'UnlockServiceDatabase', 'QueryServiceLockStatus', 'ChangeServiceConfig2', 'QueryServiceConfig2', 'DBT_CONFIGCHANGECANCELED', 'DBT_CONFIGCHANGED', 'DBT_CUSTOMEVENT', 'DBT_DEVICEARRIVAL', 'DBT_DEVICEQUERYREMOVE', 'DBT_DEVICEQUERYREMOVEFAILED', 'DBT_DEVICEREMOVECOMPLETE', 'DBT_DEVICEREMOVEPENDING', 'DBT_DEVICETYPESPECIFIC', 'DBT_QUERYCHANGECONFIG', 'DF_ALLOWOTHERACCOUNTHOOK', 'SC_ACTION_NONE', 'SC_ACTION_REBOOT', 'SC_ACTION_RESTART', 'SC_ACTION_RUN_COMMAND', 'SC_ENUM_PROCESS_INFO', 'SC_GROUP_IDENTIFIER', 'SC_MANAGER_ALL_ACCESS', 'SC_MANAGER_CONNECT', 'SC_MANAGER_CREATE_SERVICE', 'SC_MANAGER_ENUMERATE_SERVICE', 'SC_MANAGER_LOCK', 'SC_MANAGER_MODIFY_BOOT_CONFIG', 'SC_MANAGER_QUERY_LOCK_STATUS', 'SERVICE_ACCEPT_HARDWAREPROFILECHANGE', 'SERVICE_ACCEPT_NETBINDCHANGE', 'SERVICE_ACCEPT_PARAMCHANGE', 'SERVICE_ACCEPT_PAUSE_CONTINUE', 'SERVICE_ACCEPT_POWEREVENT', 'SERVICE_ACCEPT_PRESHUTDOWN', 'SERVICE_ACCEPT_SESSIONCHANGE', 'SERVICE_ACCEPT_SHUTDOWN', 'SERVICE_ACCEPT_STOP', 'SERVICE_ACTIVE', 'SERVICE_ALL_ACCESS', 'SERVICE_AUTO_START', 'SERVICE_BOOT_START', 'SERVICE_CHANGE_CONFIG', 'SERVICE_CONFIG_DELAYED_AUTO_START_INFO', 'SERVICE_CONFIG_DESCRIPTION', 'SERVICE_CONFIG_FAILURE_ACTIONS', 'SERVICE_CONFIG_FAILURE_ACTIONS_FLAG', 'SERVICE_CONFIG_PRESHUTDOWN_INFO', 'SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFO', 'SERVICE_CONFIG_SERVICE_SID_INFO', 'SERVICE_CONTINUE_PENDING', 'SERVICE_CONTROL_CONTINUE', 'SERVICE_CONTROL_DEVICEEVENT', 'SERVICE_CONTROL_HARDWAREPROFILECHANGE', 'SERVICE_CONTROL_INTERROGATE', 'SERVICE_CONTROL_NETBINDADD', 'SERVICE_CONTROL_NETBINDDISABLE', 'SERVICE_CONTROL_NETBINDENABLE', 'SERVICE_CONTROL_NETBINDREMOVE', 'SERVICE_CONTROL_PARAMCHANGE', 'SERVICE_CONTROL_PAUSE', 'SERVICE_CONTROL_POWEREVENT', 'SERVICE_CONTROL_PRESHUTDOWN', 'SERVICE_CONTROL_SESSIONCHANGE', 'SERVICE_CONTROL_SHUTDOWN', 'SERVICE_CONTROL_STOP', 'SERVICE_DEMAND_START', 'SERVICE_DISABLED', 'SERVICE_DRIVER', 'SERVICE_ENUMERATE_DEPENDENTS', 'SERVICE_ERROR_CRITICAL', 'SERVICE_ERROR_IGNORE', 'SERVICE_ERROR_NORMAL', 'SERVICE_ERROR_SEVERE', 'SERVICE_FILE_SYSTEM_DRIVER', 'SERVICE_INACTIVE', 'SERVICE_INTERACTIVE_PROCESS', 'SERVICE_INTERROGATE', 'SERVICE_KERNEL_DRIVER', 'SERVICE_NO_CHANGE', 'SERVICE_PAUSE_CONTINUE', 'SERVICE_PAUSE_PENDING', 'SERVICE_PAUSED', 'SERVICE_QUERY_CONFIG', 'SERVICE_QUERY_STATUS', 'SERVICE_RUNNING', 'SERVICE_SID_TYPE_NONE', 'SERVICE_SID_TYPE_RESTRICTED', 'SERVICE_SID_TYPE_UNRESTRICTED', 'SERVICE_SPECIFIC_ERROR', 'SERVICE_START', 'SERVICE_START_PENDING', 'SERVICE_STATE_ALL', 'SERVICE_STOP', 'SERVICE_STOP_PENDING', 'SERVICE_STOPPED', 'SERVICE_SYSTEM_START', 'SERVICE_USER_DEFINED_CONTROL', 'SERVICE_WIN32', 'SERVICE_WIN32_OWN_PROCESS', 'SERVICE_WIN32_SHARE_PROCESS', 'UOI_FLAGS', 'UOI_NAME', 'UOI_TYPE', 'UOI_USER_SID', 'WSF_VISIBLE']
import typing
import win32typing
"""An interface to the Windows NT Service API"""


def GetThreadDesktop(ThreadId:'typing.Any') -> 'win32typing.PyHDESK':
    """
    Retrieves a handle to the desktop for a thread

Args:

      ThreadId(typing.Any):Id of thread

Returns:

      win32typing.PyHDESK
        
    """
    pass
        

def EnumWindowStations() -> 'typing.Tuple[typing.Tuple[str, typing.Any], ...]':
    """
    Lists names of window stations

Args:



Returns:

      typing.Tuple[typing.Tuple[str, typing.Any], ...]
        
    """
    pass
        

def GetUserObjectInformation(Handle:'int',_type:'typing.Any') -> 'None':
    """
    Returns specified type of info about a window station or desktop

Args:

      Handle(int):Handle to window station or desktop
      _type(typing.Any):Type of info to return, one of UOI_FLAGS,UOI_NAME, UOI_TYPE, or UOI_USER_SIDReturn ValueReturn type is dependent on UOI_* constant passed in

Returns:

      None:Type of info to return, one of UOI_FLAGS,UOI_NAME, UOI_TYPE, or UOI_USER_SIDReturn ValueReturn type is dependent on UOI_* constant passed in

        
    """
    pass
        

def SetUserObjectInformation(Handle:'int',info:'typing.Any',_type:'typing.Any') -> 'None':
    """
    Set specified type of info for a window station or desktop object

Args:

      Handle(int):Handle to window station or desktop
      info(typing.Any):Information to set for handle, currently only a dictionary representing USEROBJECTFLAGS struct
      _type(typing.Any):Type of info to set, currently only accepts UOI_FLAGSCommentsCurrently only UOI_FLAGS supported

Returns:

      None
        
    """
    pass
        

def OpenWindowStation(szWinSta:'typing.Union[typing.Any]',Inherit:'typing.Any',DesiredAccess:'typing.Any') -> 'win32typing.PyHWINSTA':
    """
    Returns a handle to the specified window station

Args:

      szWinSta(typing.Union[typing.Any]):Name of window station
      Inherit(typing.Any):Allow handle to be inherited by subprocesses
      DesiredAccess(typing.Any):Bitmask of access types

Returns:

      win32typing.PyHWINSTA
        
    """
    pass
        

def OpenDesktop(szDesktop:'typing.Union[typing.Any]',Flags:'typing.Any',Inherit:'typing.Any',DesiredAccess:'typing.Any') -> 'win32typing.PyHDESK':
    """
    Opens a handle to a desktop

Args:

      szDesktop(typing.Union[typing.Any]):Name of desktop to open
      Flags(typing.Any):DF_ALLOWOTHERACCOUNTHOOK or 0
      Inherit(typing.Any):Allow handle to be inherited
      DesiredAccess(typing.Any):ACCESS_MASK specifying level of access for handle

Returns:

      win32typing.PyHDESK
        
    """
    pass
        

def CreateDesktop(Desktop:'typing.Union[typing.Any]',Flags:'typing.Any',DesiredAccess:'typing.Any',SecurityAttributes:'win32typing.PySECURITY_ATTRIBUTES') -> 'win32typing.PyHDESK':
    """
    Creates a new desktop in calling process's current window station

Args:

      Desktop(typing.Union[typing.Any]):Name of desktop to create
      Flags(typing.Any):DF_ALLOWOTHERACCOUNTHOOK or 0
      DesiredAccess(typing.Any):An ACCESS_MASK determining level of access available thru returned handle
      SecurityAttributes(win32typing.PySECURITY_ATTRIBUTES):Specifies inheritance and controls access to desktop

Returns:

      win32typing.PyHDESK
        
    """
    pass
        

def OpenInputDesktop(Flags:'typing.Any',Inherit:'typing.Any',DesiredAccess:'typing.Any') -> 'win32typing.PyHDESK':
    """
    Returns a handle to desktop for logged-in user

Args:

      Flags(typing.Any):DF_ALLOWOTHERACCOUNTHOOK or 0
      Inherit(typing.Any):Specifies if handle will be inheritable
      DesiredAccess(typing.Any):ACCESS_MASK specifying access available to returned handle

Returns:

      win32typing.PyHDESK
        
    """
    pass
        

def GetProcessWindowStation() -> 'win32typing.PyHWINSTA':
    """
    Returns a handle to calling process's current window station

Args:



Returns:

      win32typing.PyHWINSTA
        
    """
    pass
        

def CreateWindowStation(WindowStation:'typing.Union[typing.Any]',Flags:'typing.Any',DesiredAccess:'typing.Any',SecurityAttributes:'win32typing.PySECURITY_ATTRIBUTES') -> 'win32typing.PyHWINSTA':
    """
    Creates a new window station

Args:

      WindowStation(typing.Union[typing.Any]):Name of window station to create, or None
      Flags(typing.Any):CWF_CREATE_ONLY or 0
      DesiredAccess(typing.Any):Bitmask of access types available to returned handle
      SecurityAttributes(win32typing.PySECURITY_ATTRIBUTES):Specifies security for window station, and whether handle is inheritableCommentsIf name is None or empty string, name is formatteded from logon id

Returns:

      win32typing.PyHWINSTA
        
    """
    pass
        

def EnumServicesStatus(hSCManager:'win32typing.PySC_HANDLE',ServiceType:'typing.Any',ServiceState:'typing.Any') -> 'typing.Tuple[typing.Any, ...]':
    """
    Returns a tuple of status info for each service that meets specified criteria

Args:

      hSCManager(win32typing.PySC_HANDLE):Handle to service control manager as returned by win32service::OpenSCManager
      ServiceType(typing.Any):Types of services to enumerate (SERVICE_DRIVER and/or SERVICE_WIN32)
      ServiceState(typing.Any):Limits to services in specified stateReturn ValueReturns a sequence of tuples representing ENUM_SERVICE_STATUS structs: (ServiceName, DisplayName, SERVICE_STATUS)

Returns:

      typing.Tuple[typing.Any, ...]:Limits to services in specified state
Return ValueReturns a sequence of tuples representing ENUM_SERVICE_STATUS structs: (ServiceName, DisplayName, SERVICE_STATUS)

        
    """
    pass
        

def EnumServicesStatusEx(SCManager:'win32typing.PySC_HANDLE',ServiceType:'typing.Any',ServiceState:'typing.Any',InfoLevel:'typing.Any',GroupName:'typing.Any'=None) -> 'typing.Tuple[typing.Any, ...]':
    """
    Lists the status of services that meet the specified criteria

Args:

      SCManager(win32typing.PySC_HANDLE):Handle to service control manager as returned by win32service::OpenSCManager
      ServiceType(typing.Any):Types of services to enumerate (SERVICE_DRIVER and/or SERVICE_WIN32)
      ServiceState(typing.Any):Limits to services in specified state
      InfoLevel(typing.Any):Currently SC_ENUM_PROCESS_INFO is only level definedWin32 API References
      GroupName(typing.Any):Name of group - use None for all, or '' for services that don't belong to a group

Returns:

      typing.Tuple[typing.Any, ...]:Search for EnumServicesStatusEx at msdn, google or google groups.
Return ValueReturns a sequence of dicts, whose contents depend on information level requested. 

Currently, only information level supported is SC_ENUM_PROCESS_INFO (returns ENUM_SERVICE_STATUS_PROCESS).

        
    """
    pass
        

def EnumDependentServices(hService:'win32typing.PySC_HANDLE',ServiceState:'typing.Any') -> 'typing.Tuple[typing.Any, ...]':
    """
    Lists services that depend on a service

Args:

      hService(win32typing.PySC_HANDLE):Handle to service for which to list dependent services (as returned by win32service::OpenService)
      ServiceState(typing.Any):Limits to services in specified state - One of SERVICE_STATE_ALL, SERVICE_ACTIVE, SERVICE_INACTIVEReturn ValueReturns a sequence of tuples representing ENUM_SERVICE_STATUS structs: (ServiceName, DisplayName, SERVICE_STATUS)

Returns:

      typing.Tuple[typing.Any, ...]:Limits to services in specified state - One of SERVICE_STATE_ALL, SERVICE_ACTIVE, SERVICE_INACTIVE
Return ValueReturns a sequence of tuples representing ENUM_SERVICE_STATUS structs: (ServiceName, DisplayName, SERVICE_STATUS)

        
    """
    pass
        

def QueryServiceConfig(hService:'win32typing.PySC_HANDLE') -> 'typing.Any':
    """
    Retrieves configuration parameters for a service

Args:

      hService(win32typing.PySC_HANDLE):Service handle as returned by win32service::OpenServiceReturn ValueReturns a tuple representing a QUERY_SERVICE_CONFIG struct:Items[0] int : ServiceTypeCombination of SERVICE_*_DRIVER or SERVICE_*_PROCESS constants[1] int : StartTypeOne of SERVICE_*_START constants[2] int : ErrorControlOne of SERVICE_ERROR_* constants[3] PyUnicode : BinaryPathNameService's binary executable, can also contain command line args[4] PyUnicode : LoadOrderGroupLoading group that service is a member of[5] int : TagIdOrder of service within its load order group[6] [PyUnicode,...] : DependenciesSequence of names of services on which this service depends[7] PyUnicode : ServiceStartNameAccount name under which service will run[8] PyUnicode : DisplayNameName of service

Returns:

      typing.Any:Service handle as returned by win32service::OpenServiceReturn ValueReturns a tuple representing a QUERY_SERVICE_CONFIG struct:
Items[0] int : ServiceType
Combination of SERVICE_*_DRIVER or SERVICE_*_PROCESS constants
[1] int : StartType
One of SERVICE_*_START constants
[2] int : ErrorControl
One of SERVICE_ERROR_* constants
[3] PyUnicode : BinaryPathName
Service's binary executable, can also contain command line args
[4] PyUnicode : LoadOrderGroup
Loading group that service is a member of
[5] int : TagId
Order of service within its load order group
[6] [PyUnicode,...] : Dependencies
Sequence of names of services on which this service depends
[7] PyUnicode : ServiceStartName
Account name under which service will run
[8] PyUnicode : DisplayName
Name of service

        
    """
    pass
        

def StartService(hService:'win32typing.PySC_HANDLE',args:'typing.List[str]') -> 'None':
    """
    Starts the specified service

Args:

      hService(win32typing.PySC_HANDLE):Handle to the service to be started
      args(typing.List[str]):Arguments to the service.

Returns:

      None
        
    """
    pass
        

def OpenService(scHandle:'win32typing.PySC_HANDLE',name:'str',desiredAccess:'typing.Any') -> 'win32typing.PySC_HANDLE':
    """
    Returns a handle to the specified service.

Args:

      scHandle(win32typing.PySC_HANDLE):Handle to the Service Control Mananger
      name(str):The name of the service to open.
      desiredAccess(typing.Any):The access desired.

Returns:

      win32typing.PySC_HANDLE
        
    """
    pass
        

def OpenSCManager(machineName:'str',dbName:'str',desiredAccess:'typing.Any') -> 'win32typing.PySC_HANDLE':
    """
    Returns a handle to the service control manager

Args:

      machineName(str):The name of the computer, or None
      dbName(str):The name of the service database, or None
      desiredAccess(typing.Any):The access desired. (combination of win32service.SC_MANAGER_* flags)

Returns:

      win32typing.PySC_HANDLE
        
    """
    pass
        

def CloseServiceHandle(scHandle:'win32typing.PySC_HANDLE') -> 'None':
    """
    Closes a service or SCM handle

Args:

      scHandle(win32typing.PySC_HANDLE):Handle to close

Returns:

      None
        
    """
    pass
        

def QueryServiceStatus(hService:'win32typing.PySC_HANDLE') -> 'win32typing.SERVICE_STATUS':
    """
    Queries a service status

Args:

      hService(win32typing.PySC_HANDLE):Handle to service to be queried

Returns:

      win32typing.SERVICE_STATUS
        
    """
    pass
        

def QueryServiceStatusEx(hService:'win32typing.PySC_HANDLE') -> 'win32typing.SERVICE_STATUS':
    """
    Queries a service status

Args:

      hService(win32typing.PySC_HANDLE):Handle to service to be queried

Returns:

      win32typing.SERVICE_STATUS
        
    """
    pass
        

def SetServiceObjectSecurity(Handle:'win32typing.PySC_HANDLE',SecurityInformation:'typing.Any',SecurityDescriptor:'win32typing.PySECURITY_DESCRIPTOR') -> 'None':
    """
    Set the security descriptor for a service

Args:

      Handle(win32typing.PySC_HANDLE):Service handle
      SecurityInformation(typing.Any):Type of infomation to set, combination of values from SECURITY_INFORMATION enum
      SecurityDescriptor(win32typing.PySECURITY_DESCRIPTOR):PySECURITY_DESCRIPTOR containing infomation to set

Returns:

      None
        
    """
    pass
        

def QueryServiceObjectSecurity(Handle:'win32typing.PySC_HANDLE',SecurityInformation:'typing.Any') -> 'win32typing.PySECURITY_DESCRIPTOR':
    """
    Retrieves information from the security descriptor for a service

Args:

      Handle(win32typing.PySC_HANDLE):Service handle
      SecurityInformation(typing.Any):Type of infomation to retrieve, combination of values from SECURITY_INFORMATION enum

Returns:

      win32typing.PySECURITY_DESCRIPTOR
        
    """
    pass
        

def GetServiceKeyName(hSCManager:'win32typing.PySC_HANDLE',DisplayName:'typing.Any') -> 'typing.Any':
    """
    Translates a service display name into its registry key name

Args:

      hSCManager(win32typing.PySC_HANDLE):Handle to service control manager as returned by win32service::OpenSCManager
      DisplayName(typing.Any):Display name of a service

Returns:

      typing.Any
        
    """
    pass
        

def GetServiceDisplayName(hSCManager:'win32typing.PySC_HANDLE',ServiceName:'typing.Any') -> 'typing.Any':
    """
    Translates an internal service name into its display name

Args:

      hSCManager(win32typing.PySC_HANDLE):Handle to service control manager as returned by win32service::OpenSCManager
      ServiceName(typing.Any):Name of service

Returns:

      typing.Any
        
    """
    pass
        

def SetServiceStatus(scHandle:'typing.Any',serviceStatus:'win32typing.SERVICE_STATUS') -> 'None':
    """
    Sets a service status

Args:

      scHandle(typing.Any):Handle to set
      serviceStatus(win32typing.SERVICE_STATUS):The new status

Returns:

      None
        
    """
    pass
        

def ControlService(scHandle:'win32typing.PySC_HANDLE',code:'typing.Any') -> 'win32typing.SERVICE_STATUS':
    """
    Sends a control message to a service.

Args:

      scHandle(win32typing.PySC_HANDLE):Handle to control
      code(typing.Any):The service control code.Return ValueThe result is the new service status.

Returns:

      win32typing.SERVICE_STATUS:The service control code.Return ValueThe result is the new service status.

        
    """
    pass
        

def DeleteService(scHandle:'win32typing.PySC_HANDLE') -> 'None':
    """
    Deletes the specified service

Args:

      scHandle(win32typing.PySC_HANDLE):Handle to service to be deleted

Returns:

      None
        
    """
    pass
        

def CreateService(scHandle:'win32typing.PySC_HANDLE',name:'str',displayName:'str',desiredAccess:'typing.Any',serviceType:'typing.Any',startType:'typing.Any',errorControl:'typing.Any',binaryFile:'str',loadOrderGroup:'str',bFetchTag:'typing.Any',serviceDeps:'typing.List[typing.Any]',acctName:'str',password:'str') -> 'typing.Tuple[typing.Union[win32typing.PySC_HANDLE], typing.Any]':
    """
    Creates a new service.

Args:

      scHandle(win32typing.PySC_HANDLE):handle to service control manager database
      name(str):Name of service
      displayName(str):Display name
      desiredAccess(typing.Any):type of access to service
      serviceType(typing.Any):type of service
      startType(typing.Any):When/how to start service
      errorControl(typing.Any):severity if service fails to start
      binaryFile(str):name of binary file
      loadOrderGroup(str):name of load ordering group , or None
      bFetchTag(typing.Any):Should the tag be fetched and returned?  If TRUE, the result is a tuple of (handle, tag), otherwise just handle.
      serviceDeps(typing.List[typing.Any]):sequence of dependency names
      acctName(str):account name of service, or None
      password(str):password for service account , or None

Returns:

      typing.Tuple[typing.Union[win32typing.PySC_HANDLE], typing.Any]
        
    """
    pass
        

def ChangeServiceConfig(hService:'win32typing.PySC_HANDLE',serviceType:'typing.Any',startType:'typing.Any',errorControl:'typing.Any',binaryFile:'str',loadOrderGroup:'str',bFetchTag:'typing.Any',serviceDeps:'typing.List[typing.Any]',acctName:'str',password:'str',displayName:'str') -> 'typing.Union[typing.Any]':
    """
    Changes the configuration of an existing service.

Args:

      hService(win32typing.PySC_HANDLE):handle to service to be modified
      serviceType(typing.Any):type of service, or SERVICE_NO_CHANGE
      startType(typing.Any):When/how to start service, or SERVICE_NO_CHANGE
      errorControl(typing.Any):severity if service fails to start, or SERVICE_NO_CHANGE
      binaryFile(str):name of binary file, or None
      loadOrderGroup(str):name of load ordering group , or None
      bFetchTag(typing.Any):Should the tag be fetched and returned?  If TRUE, the result is the tag, else None.
      serviceDeps(typing.List[typing.Any]):sequence of dependency names
      acctName(str):account name of service, or None
      password(str):password for service account , or None
      displayName(str):Display name

Returns:

      typing.Union[typing.Any]
        
    """
    pass
        

def LockServiceDatabase(sc_handle:'win32typing.PySC_HANDLE') -> 'typing.Any':
    """
    Locks the service database.

Args:

      sc_handle(win32typing.PySC_HANDLE):A handle to the SCM.

Returns:

      typing.Any
        
    """
    pass
        

def UnlockServiceDatabase(lock:'typing.Any') -> 'typing.Any':
    """
    Unlocks the service database.

Args:

      lock(typing.Any):A lock provided by win32service::LockServiceDatabase

Returns:

      typing.Any
        
    """
    pass
        

def QueryServiceLockStatus(hSCManager:'win32typing.PySC_HANDLE') -> 'typing.Tuple[typing.Any, str, typing.Any]':
    """
    Retrieves the lock status of the specified service control manager database.

Args:

      hSCManager(win32typing.PySC_HANDLE):Handle to the SCM.Return ValueThe result is a tuple of (bIsLocked, userName, lockDuration)

Returns:

      typing.Tuple[typing.Any, str, typing.Any]:Handle to the SCM.Return ValueThe result is a tuple of (bIsLocked, userName, lockDuration)

        
    """
    pass
        

def ChangeServiceConfig2(hService:'win32typing.PySC_HANDLE',InfoLevel:'typing.Any',info:'typing.Any') -> 'None':
    """
    Modifies advanced service parameters

Args:

      hService(win32typing.PySC_HANDLE):Service handle as returned by win32service::OpenService
      InfoLevel(typing.Any):One of win32service.SERVICE_CONFIG_* values
      info(typing.Any):Type depends on InfoLevelInfoLevelInput valueSERVICE_CONFIG_DESCRIPTIONUnicode stringSERVICE_CONFIG_FAILURE_ACTIONSDict representing a SERVICE_FAILURE_ACTIONS structSERVICE_CONFIG_DELAYED_AUTO_START_INFOBooleanSERVICE_CONFIG_FAILURE_ACTIONS_FLAGBooleanSERVICE_CONFIG_PRESHUTDOWN_INFOint (shutdown timeout in milliseconds)SERVICE_CONFIG_SERVICE_SID_INFOint (SERVICE_SID_TYPE_*)SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFOSequence of unicode strings

Returns:

      None
        
    """
    pass
        

def QueryServiceConfig2(hService:'win32typing.PySC_HANDLE',InfoLevel:'typing.Any') -> 'typing.Any':
    """
    Retrieves advanced service configuration options

Args:

      hService(win32typing.PySC_HANDLE):Service handle as returned by win32service::OpenService
      InfoLevel(typing.Any):One of win32service.SERVICE_CONFIG_* valuesInfoLevelType of value returnedSERVICE_CONFIG_DESCRIPTIONUnicode stringSERVICE_CONFIG_FAILURE_ACTIONSDict representing a SERVICE_FAILURE_ACTIONS structSERVICE_CONFIG_DELAYED_AUTO_START_INFOBooleanSERVICE_CONFIG_FAILURE_ACTIONS_FLAGBooleanSERVICE_CONFIG_PRESHUTDOWN_INFOint (shutdown timeout in milliseconds)SERVICE_CONFIG_SERVICE_SID_INFOint (SERVICE_SID_TYPE_*)SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFOList of unicode stringsReturn ValueType of returned object depends on InfoLevel

Returns:

      typing.Any:One of win32service.SERVICE_CONFIG_* values


InfoLevel


Type of value returned



SERVICE_CONFIG_DESCRIPTIONUnicode string
SERVICE_CONFIG_FAILURE_ACTIONSDict representing a SERVICE_FAILURE_ACTIONS struct
SERVICE_CONFIG_DELAYED_AUTO_START_INFOBoolean
SERVICE_CONFIG_FAILURE_ACTIONS_FLAGBoolean
SERVICE_CONFIG_PRESHUTDOWN_INFOint (shutdown timeout in milliseconds)
SERVICE_CONFIG_SERVICE_SID_INFOint (SERVICE_SID_TYPE_*)
SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFOList of unicode strings
Return ValueType of returned object depends on InfoLevel

        
    """
    pass
        
DBT_CONFIGCHANGECANCELED = ...
DBT_CONFIGCHANGED = ...
DBT_CUSTOMEVENT = ...
DBT_DEVICEARRIVAL = ...
DBT_DEVICEQUERYREMOVE = ...
DBT_DEVICEQUERYREMOVEFAILED = ...
DBT_DEVICEREMOVECOMPLETE = ...
DBT_DEVICEREMOVEPENDING = ...
DBT_DEVICETYPESPECIFIC = ...
DBT_QUERYCHANGECONFIG = ...
DF_ALLOWOTHERACCOUNTHOOK = ...
SC_ACTION_NONE = ...
SC_ACTION_REBOOT = ...
SC_ACTION_RESTART = ...
SC_ACTION_RUN_COMMAND = ...
SC_ENUM_PROCESS_INFO = ...
SC_GROUP_IDENTIFIER = ...
SC_MANAGER_ALL_ACCESS = ...
SC_MANAGER_CONNECT = ...
SC_MANAGER_CREATE_SERVICE = ...
SC_MANAGER_ENUMERATE_SERVICE = ...
SC_MANAGER_LOCK = ...
SC_MANAGER_MODIFY_BOOT_CONFIG = ...
SC_MANAGER_QUERY_LOCK_STATUS = ...
SERVICE_ACCEPT_HARDWAREPROFILECHANGE = ...
SERVICE_ACCEPT_NETBINDCHANGE = ...
SERVICE_ACCEPT_PARAMCHANGE = ...
SERVICE_ACCEPT_PAUSE_CONTINUE = ...
SERVICE_ACCEPT_POWEREVENT = ...
SERVICE_ACCEPT_PRESHUTDOWN = ...
SERVICE_ACCEPT_SESSIONCHANGE = ...
SERVICE_ACCEPT_SHUTDOWN = ...
SERVICE_ACCEPT_STOP = ...
SERVICE_ACTIVE = ...
SERVICE_ALL_ACCESS = ...
SERVICE_AUTO_START = ...
SERVICE_BOOT_START = ...
SERVICE_CHANGE_CONFIG = ...
SERVICE_CONFIG_DELAYED_AUTO_START_INFO = ...
SERVICE_CONFIG_DESCRIPTION = ...
SERVICE_CONFIG_FAILURE_ACTIONS = ...
SERVICE_CONFIG_FAILURE_ACTIONS_FLAG = ...
SERVICE_CONFIG_PRESHUTDOWN_INFO = ...
SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFO = ...
SERVICE_CONFIG_SERVICE_SID_INFO = ...
SERVICE_CONTINUE_PENDING = ...
SERVICE_CONTROL_CONTINUE = ...
SERVICE_CONTROL_DEVICEEVENT = ...
SERVICE_CONTROL_HARDWAREPROFILECHANGE = ...
SERVICE_CONTROL_INTERROGATE = ...
SERVICE_CONTROL_NETBINDADD = ...
SERVICE_CONTROL_NETBINDDISABLE = ...
SERVICE_CONTROL_NETBINDENABLE = ...
SERVICE_CONTROL_NETBINDREMOVE = ...
SERVICE_CONTROL_PARAMCHANGE = ...
SERVICE_CONTROL_PAUSE = ...
SERVICE_CONTROL_POWEREVENT = ...
SERVICE_CONTROL_PRESHUTDOWN = ...
SERVICE_CONTROL_SESSIONCHANGE = ...
SERVICE_CONTROL_SHUTDOWN = ...
SERVICE_CONTROL_STOP = ...
SERVICE_DEMAND_START = ...
SERVICE_DISABLED = ...
SERVICE_DRIVER = ...
SERVICE_ENUMERATE_DEPENDENTS = ...
SERVICE_ERROR_CRITICAL = ...
SERVICE_ERROR_IGNORE = ...
SERVICE_ERROR_NORMAL = ...
SERVICE_ERROR_SEVERE = ...
SERVICE_FILE_SYSTEM_DRIVER = ...
SERVICE_INACTIVE = ...
SERVICE_INTERACTIVE_PROCESS = ...
SERVICE_INTERROGATE = ...
SERVICE_KERNEL_DRIVER = ...
SERVICE_NO_CHANGE = ...
SERVICE_PAUSE_CONTINUE = ...
SERVICE_PAUSE_PENDING = ...
SERVICE_PAUSED = ...
SERVICE_QUERY_CONFIG = ...
SERVICE_QUERY_STATUS = ...
SERVICE_RUNNING = ...
SERVICE_SID_TYPE_NONE = ...
SERVICE_SID_TYPE_RESTRICTED = ...
SERVICE_SID_TYPE_UNRESTRICTED = ...
SERVICE_SPECIFIC_ERROR = ...
SERVICE_START = ...
SERVICE_START_PENDING = ...
SERVICE_STATE_ALL = ...
SERVICE_STOP = ...
SERVICE_STOP_PENDING = ...
SERVICE_STOPPED = ...
SERVICE_SYSTEM_START = ...
SERVICE_USER_DEFINED_CONTROL = ...
SERVICE_WIN32 = ...
SERVICE_WIN32_OWN_PROCESS = ...
SERVICE_WIN32_SHARE_PROCESS = ...
UOI_FLAGS = ...
UOI_NAME = ...
UOI_TYPE = ...
UOI_USER_SID = ...
WSF_VISIBLE = ...



__all__=['', 'CreatePhonebookEntry', 'Dial', 'EditPhonebookEntry', 'EnumConnections', 'EnumEntries', 'GetConnectStatus', 'GetEntryDialParams', 'GetErrorString', 'HangUp', 'IsHandleValid', 'SetEntryDialParams', 'RASCS_AllDevicesConnected', 'RASCS_AuthAck', 'RASCS_AuthCallback', 'RASCS_AuthChangePassword', 'RASCS_Authenticate', 'RASCS_Authenticated', 'RASCS_AuthLinkSpeed', 'RASCS_AuthNotify', 'RASCS_AuthProject', 'RASCS_AuthRetry', 'RASCS_CallbackComplete', 'RASCS_CallbackSetByCaller', 'RASCS_ConnectDevice', 'RASCS_Connected', 'RASCS_DeviceConnected', 'RASCS_Disconnected', 'RASCS_Interactive', 'RASCS_LogonNetwork', 'RASCS_OpenPort', 'RASCS_PasswordExpired', 'RASCS_PortOpened', 'RASCS_PrepareForCallback', 'RASCS_Projected', 'RASCS_ReAuthenticate', 'RASCS_RetryAuthentication', 'RASCS_StartAuthentication', 'RASCS_WaitForCallback', 'RASCS_WaitForModemReset']
import typing
import win32typing
"""A module encapsulating the Windows Remote Access Service (RAS) API."""


def CreatePhonebookEntry(hWnd:'typing.Any',fileName:'str'=None) -> 'None':
    """
    Creates a new phonebook entry.  The function displays a dialog box into 

which the user can enter information about the entry

Args:

      hWnd(typing.Any):Handle to the parent window of the dialog box.
      fileName(str):Specifies the filename of the phonebook entry. Currently this is ignored.Win32 API References

Returns:

      None
        
    """
    pass
        

def Dial(dialExtensions:'typing.Any',fileName:'str',RasDialParams:'win32typing.RASDIALPARAMS',callback:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Establishes a RAS connection to a RAS server.

Args:

      dialExtensions(typing.Any):An object providing the RASDIALEXTENSIONS information, or None
      fileName(str):Specifies the filename of the phonebook entry, or None.  Ignored on Win95.
      RasDialParams(win32typing.RASDIALPARAMS):A tuple describing a RASDIALPARAMS structure.
      callback(typing.Any):The method to be called when RAS events occur, or None. If not None, the function must have the signature of win32ras::RasDialFunc1CommentsNote - this handle must be closed using win32ras::HangUp, or else the RAS port will remain open, even after the program has terminated. Your operating system may need rebooting to clean up otherwise!Win32 API References

Returns:

      typing.Tuple[typing.Any, typing.Any]:Search for RasDial at msdn, google or google groups.
Return ValueThe return value is (handle, retCode). 

It is possible for a valid handle to be returned even on failure. 

If the returned handle is = 0, then it can be assumed invalid.

        
    """
    pass
        

def EditPhonebookEntry(hWnd:'typing.Any',fileName:'str',entryName:'str'=None) -> 'None':
    """
    Creates a new phonebook entry.  The function displays a dialog box into which 

the user can enter information about the entry

Args:

      hWnd(typing.Any):Handle to the parent window of the dialog box.
      fileName(str):Specifies the filename of the phonebook entry, or None.  Currently this is ignored.
      entryName(str):Specifies the name of the phonebook entry to editWin32 API References

Returns:

      None
        
    """
    pass
        

def EnumConnections() -> 'typing.Any':
    """
    Returns a list of tuples, one for each active connection.

Args:



Returns:

      typing.Any:Search for RasEnumConnections at msdn, google or google groups.
Return ValueEach tuple is of format (handle, entryName, deviceType, deviceName)

        
    """
    pass
        

def EnumEntries(reserved:'str'=None,fileName:'str'=None) -> 'None':
    """
    Returns a list of tuples, one for each phonebook entry.

Args:

      reserved(str):Reserved - must be None
      fileName(str):The name of the phonebook file, or None.

Returns:

      None
        
    """
    pass
        

def GetConnectStatus(hrasconn:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any, str, str]':
    """
    Returns a tuple with connection information.

Args:

      hrasconn(typing.Any):Handle to the RAS session.Win32 API References

Returns:

      typing.Tuple[typing.Any, typing.Any, str, str]
        
    """
    pass
        

def GetEntryDialParams(fileName:'str',entryName:'str') -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Returns a tuple with the most recently set dial parameters for 

the specified entry.

Args:

      fileName(str):The filename of the phonebook, or None.
      entryName(str):The name of the entry to retrieve the params for.Win32 API References

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any, typing.Any, typing.Any, typing.Any]:Search for RasGetConnectStatus at msdn, google or google groups.
Return ValueThe return value is a tuple describing the params retrieved, plus a BOOL integer 

indicating if the password was also retrieved.

        
    """
    pass
        

def GetErrorString(error:'typing.Any') -> 'str':
    """
    Returns an error string for a RAS error code.

Args:

      error(typing.Any):The error value being queried.Win32 API References

Returns:

      str
        
    """
    pass
        

def HangUp(hras:'typing.Any') -> 'None':
    """
    Terminates a remote access session.

Args:

      hras(typing.Any):The handle to the RAS connection to be terminated.Win32 API References

Returns:

      None
        
    """
    pass
        

def IsHandleValid(hras:'typing.Any') -> 'None':
    """
    Indicates if the given RAS handle is valid.

Args:

      hras(typing.Any):The handle to the RAS connection being checked.

Returns:

      None
        
    """
    pass
        

def SetEntryDialParams(fileName:'str',RasDialParams:'typing.Any',bSavePassword:'typing.Any') -> 'None':
    """
    Sets the dial parameters for the specified entry.

Args:

      fileName(str):The filename of the phonebook, or None.
      RasDialParams(typing.Any):A tuple describing a RASDIALPARAMS structure.
      bSavePassword(typing.Any):Indicates whether to remove password from entry's parameters.Win32 API References

Returns:

      None
        
    """
    pass
        
RASCS_AllDevicesConnected = ...
RASCS_AuthAck = ...
RASCS_AuthCallback = ...
RASCS_AuthChangePassword = ...
RASCS_Authenticate = ...
RASCS_Authenticated = ...
RASCS_AuthLinkSpeed = ...
RASCS_AuthNotify = ...
RASCS_AuthProject = ...
RASCS_AuthRetry = ...
RASCS_CallbackComplete = ...
RASCS_CallbackSetByCaller = ...
RASCS_ConnectDevice = ...
RASCS_Connected = ...
RASCS_DeviceConnected = ...
RASCS_Disconnected = ...
RASCS_Interactive = ...
RASCS_LogonNetwork = ...
RASCS_OpenPort = ...
RASCS_PasswordExpired = ...
RASCS_PortOpened = ...
RASCS_PrepareForCallback = ...
RASCS_Projected = ...
RASCS_ReAuthenticate = ...
RASCS_RetryAuthentication = ...
RASCS_StartAuthentication = ...
RASCS_WaitForCallback = ...
RASCS_WaitForModemReset = ...
